Logical. Defaults to TRUE display download progress
bar. The progress bar only reflects only the downloading
time, not the time to load the data to memory.
cache
Logical. Whether the function should read the data cached
locally, which is much faster. Defaults to TRUE. The first time the
user runs the function, censobr will download the file and store it
locally so that the file only needs to be download once. If FALSE,
the function will download the data again and overwrite the local file.
verbose
A logical. Whether the function should print informative
messages. Defaults to TRUE.
if (FALSE) { # identical(tolower(Sys.getenv("NOT_CRAN")), "true")# Open interview manual on the browserinterview_manual(
year = 2010,
showProgress = FALSE )
}